Function bsn1::contents::to_bool_der[][src]

pub const fn to_bool_der(bytes: &[u8]) -> Result<bool, Error>
Parses bytes as a DER contents of Bool.

This function is valid only for the contents of DER, and not applied to the contents of ‘CER’ nor ‘BER.’