Function bsn1::contents::to_bool_ber [−][src]
Parses bytes as a BER contents of Bool.
This function is valid only for the contents of BER, and not applied to the contents of DER nor CER.
Parses bytes as a BER contents of Bool.
This function is valid only for the contents of BER, and not applied to the contents of DER nor CER.