Struct bsn1::Id[][src]

pub struct Id { /* fields omitted */ }

Id owns IdRef and represents Identifier.

Implementations

impl Id[src]

pub fn new(class: ClassTag, pc: PCTag, number: u128) -> Self[src]

Creates a new instance from class , pc , and number .

Warnings

ASN.1 reserves some universal identifier numbers and they should not be used, however, this function ignores that. For example, number 15 (0x0f) is reserved so far, but this function accepts such a number.

Examples

use bsn1::{ClassTag, Id, PCTag};

// Creates 'Universal Integer'
let _id = Id::new(ClassTag::Universal, PCTag::Primitive, 2);

Methods from Deref<Target = IdRef>

pub fn class(&self) -> ClassTag[src]

Returns ClassTag of self .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Universal, PCTag::Primitive, 0);
assert_eq!(ClassTag::Universal, id.class());

let id = Id::new(ClassTag::Application, PCTag::Constructed, 1);
assert_eq!(ClassTag::Application, id.class());

let id = Id::new(ClassTag::ContextSpecific, PCTag::Primitive, 2);
assert_eq!(ClassTag::ContextSpecific, id.class());

let id = Id::new(ClassTag::Private, PCTag::Constructed, 3);
assert_eq!(ClassTag::Private, id.class());

pub fn is_universal(&self) -> bool[src]

Returns true if self is ‘Universal’ class, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Universal, PCTag::Primitive, 0);
assert_eq!(true, id.is_universal());

pub fn is_application(&self) -> bool[src]

Returns true if self is ‘Application’ class, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Application, PCTag::Primitive, 0);
assert_eq!(true, id.is_application());

pub fn is_context_specific(&self) -> bool[src]

Returns true if self is ‘Context Specific’ class, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::ContextSpecific, PCTag::Primitive, 0);
assert_eq!(true, id.is_context_specific());

pub fn is_private(&self) -> bool[src]

Returns true if self is ‘Private’ class, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Private, PCTag::Primitive, 0);
assert_eq!(true, id.is_private());

pub fn pc(&self) -> PCTag[src]

Returns the Primitive/Constructed flag of self .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Universal, PCTag::Primitive, 0);
assert_eq!(PCTag::Primitive, id.pc());

let id = Id::new(ClassTag::Application, PCTag::Constructed, 1);
assert_eq!(PCTag::Constructed, id.pc());

pub fn is_primitive(&self) -> bool[src]

Returns true if self is flagged as ‘Primitive’, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Universal, PCTag::Primitive, 0);
assert_eq!(true, id.is_primitive());

pub fn is_constructed(&self) -> bool[src]

Returns true if self is flagged as ‘Constructed’, or false .

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Universal, PCTag::Constructed, 0);
assert_eq!(true, id.is_constructed());

pub fn number(&self) -> Result<u128, Error>[src]

Returns the number of self unless overflow.

Examples

use bsn1::{ClassTag, Id, PCTag};

// 'Id' implements 'Deref<Target = IdRef>'.
let id = Id::new(ClassTag::Application, PCTag::Primitive, 49);
assert_eq!(49, id.number().unwrap());